import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "components"
import "view"

import Artix.Handlers
import Artix.Core
import Artix.Gui
import Artix.Models

/**
 * @brief Форма информации о программе
 */
FullscreenDialog {

    component InfoBox: GroupBox {
        Style.class: "programInfoCommonData"
        interactive: false
        leftPadding: 32
        topPadding: 24
        rightPadding: 32
        bottomPadding: 24
    }

    contentItem: RowLayout {
        spacing: 0
        Rectangle {
            id: contentRect
            Layout.fillWidth: true
            Layout.fillHeight: true
            color: Style.parameter("color.modalBackground")
            Flickable {
                id: flickable
                anchors.fill: parent
                contentHeight: content.implicitHeight + 24
                interactive: contentHeight > (contentRect.height)
                ColumnLayout {
                    id: content
                    anchors {
                        left: parent.left; right: parent.right; top: parent.top
                        leftMargin: 24; topMargin: 16; rightMargin: 24
                    }
                    spacing: 16
                    BasicLabel {
                        Style.class: "programInfoTitle"
                        Tr { code: "programInfoTitle"; defaultMessage: "Информация о программе" }
                    }
                    Item { Layout.preferredHeight: 0 } // двойной spacing
                    // Информации о версии программы
                    RowLayout {
                        spacing: 16
                        GroupBox {
                            Style.class: "programInfoMainData"
                            Layout.preferredWidth: (content.width - parent.spacing) / 2
                            interactive: false
                            padding: 24
                            leftPadding: 32
                            rightPadding: 32
                            contentItem: ColumnLayout {
                                spacing: 4
                                RowLayout {
                                    spacing: 4
                                    BasicLabel {
                                        Style.class: "programInfoVersionTitle"
                                        Tr { code: "programInfoVersion"; defaultMessage: "Версия" }
                                    }
                                    BasicLabel {
                                        Style.class: "programInfoVersionDate"
                                        text: "(" + params.version.date + " " + params.version.time + ")"
                                    }
                                }
                                BasicLabel {
                                    Style.class: "programInfoVersionValue"
                                    Layout.fillWidth: true
                                    elide: Text.ElideRight
                                    text: params.version.version + "-" + params.version.revision
                                }
                            }
                        }
                        InfoBox {
                            Layout.preferredWidth: (content.width - parent.spacing) / 2
                            interactive: false
                            contentItem: ColumnLayout {
                                spacing: 4
                                BasicLabel {
                                    Style.class: "programInfoVersionTitle"
                                    Layout.fillWidth: true
                                    Tr { code: "programInfoBuild"; defaultMessage: "Сборка" }
                                }
                                BasicLabel {
                                    Style.class: "programInfoVersionValue"
                                    Layout.fillWidth: true
                                    text: params.version.metaVersion
                                }
                            }
                        }
                    }
                    // Информация о версии ФР
                    InfoBox {
                        Layout.fillWidth: true
                        interactive: false
                        visible: params.frInfo
                        contentItem: ColumnLayout {
                            spacing: 4
                            BasicLabel {
                                Style.class: "programInfoVersionTitle"
                                Layout.fillWidth: true
                                Tr { code: "programInfoFrFirmwareVersion"; defaultMessage: "Версия ПО ФР" }
                            }
                            BasicLabel {
                                Style.class: "programInfoVersionValue"
                                Layout.fillWidth: true
                                text: params.frInfo
                            }
                        }
                    }
                    // Информация об установленных пакетах
                    InfoBox {
                        Layout.fillWidth: true
                        interactive: false
                        contentItem: ColumnLayout {
                            spacing: 0
                            BasicLabel {
                                Style.class: "programInfoCommonTitle"
                                Layout.fillWidth: true
                                Tr { code: "programInfoModules"; defaultMessage: "Установленные модули" }
                            }
                            Item { Layout.preferredHeight: 8 }
                            Control {
                                Layout.fillWidth: true
                                topPadding: 16
                                bottomPadding: 16
                                leftPadding: 8
                                rightPadding: 8
                                contentItem: RowLayout {
                                    spacing: 0
                                    BasicLabel {
                                        Style.class: "programInfoTableTitle"
                                        Layout.preferredWidth: parent.width / 5 * 3
                                        Tr { code: "programInfoModulName"; defaultMessage: "Наименование" }
                                    }
                                    BasicLabel {
                                        Style.class: "programInfoTableTitle"
                                        Layout.preferredWidth: parent.width / 5 * 2
                                        Tr { code: "programInfoModulVersion"; defaultMessage: "Версия" }
                                    }
                                }
                                Line {
                                    anchors.bottom: parent.bottom
                                    strokeWidth: 2
                                    width: parent.width
                                    color: Style.parameter("color.grayDark")
                                }
                            }
                            Repeater {
                                model: params.packagesInfo
                                delegate: Control {
                                    required property var modelData
                                    Layout.fillWidth: true
                                    topPadding: 16
                                    bottomPadding: 16
                                    leftPadding: 8
                                    rightPadding: 8
                                    contentItem: RowLayout {
                                        spacing: 0
                                        BasicLabel {
                                            Style.class: "programInfoTableValue"
                                            Layout.preferredWidth: parent.width / 5 * 3
                                            text: modelData.package
                                        }
                                        BasicLabel {
                                            Style.class: "programInfoTableValue"
                                            Layout.preferredWidth: parent.width / 5 * 2
                                            text: modelData.version
                                        }
                                    }
                                    Line {
                                        anchors.bottom: parent.bottom
                                        strokeWidth: 2
                                        width: parent.width
                                        color: Style.parameter("color.grayBorder")
                                    }
                                }
                            }
                        }
                    }
                    // Информация о сетевых интерфейсах
                    InfoBox {
                        Layout.fillWidth: true
                        interactive: false
                        contentItem: ColumnLayout {
                            spacing: 0
                            BasicLabel {
                                Style.class: "programInfoCommonTitle"
                                Layout.fillWidth: true
                                Tr { code: "programInfoNetworkTitle"; defaultMessage: "Информация о сети" }
                            }
                            Item { Layout.preferredHeight: 8 }
                            Control {
                                Layout.fillWidth: true
                                topPadding: 16
                                bottomPadding: 16
                                leftPadding: 8
                                rightPadding: 8
                                contentItem: RowLayout {
                                    spacing: 0
                                    BasicLabel {
                                        Style.class: "programInfoTableTitle"
                                        Layout.preferredWidth: parent.width / 5 * 3
                                        verticalAlignment: Label.AlignTop
                                        Tr { code: "programInfoNetworkInterface"; defaultMessage: "Интерфейс" }
                                    }
                                    BasicLabel {
                                        Style.class: "programInfoTableTitle"
                                        Layout.preferredWidth: parent.width / 5 * 2
                                        Tr { code: "programInfoNetworkAddress"; defaultMessage: "Адрес" }
                                    }
                                }
                                Line {
                                    anchors.bottom: parent.bottom
                                    strokeWidth: 2
                                    width: parent.width
                                    color: Style.parameter("color.grayDark")
                                }
                            }
                            Repeater {
                                model: HashModel { hash: params.networkInterfaceInfo }
                                delegate: Control {
                                    required property string key
                                    required property var value
                                    Layout.fillWidth: true
                                    topPadding: 16
                                    bottomPadding: 16
                                    leftPadding: 8
                                    rightPadding: 8
                                    contentItem: RowLayout {
                                        spacing: 0
                                        BasicLabel {
                                            Style.class: "programInfoTableValue"
                                            Layout.preferredWidth: parent.width / 5 * 3
                                            Layout.preferredHeight: networkValue.implicitHeight
                                            verticalAlignment: Label.AlignTop
                                            text: key
                                        }
                                        BasicLabel {
                                            id: networkValue
                                            Style.class: "programInfoTableValue"
                                            Layout.preferredWidth: parent.width / 5 * 2
                                            text: value
                                        }
                                    }
                                    Line {
                                        anchors.bottom: parent.bottom
                                        strokeWidth: 2
                                        width: parent.width
                                        color: Style.parameter("color.grayBorder")
                                    }
                                }
                            }
                        }
                    }
                }
                ScrollBar.vertical: ScrollBar {
                    id: scrollBar
                    Timer {
                        id: scrollTimer
                        interval: 2500
                        onTriggered: parent.active = false
                    }
                    onActiveChanged: scrollTimer.start()
                }
            }
        }
        Item {
            Layout.fillHeight: true
            Layout.preferredWidth: 304
            TopPanel {
                anchors { left: parent.left; top: parent.top; right: parent.right }
                anchors.leftMargin: 24
                hideUserName: true
            }
            ColumnLayout {
                anchors { left: parent.left; right: parent.right; bottom: parent.bottom; margins: 24 }
                spacing: 8
                BasicButton {
                    Style.class: "programInfoCancel"
                    Layout.fillWidth: true
                    Layout.preferredHeight: 68
                    Tr { code: "backButton"; defaultMessage: "Назад" }
                    onClicked: handler.sendAnswer()
                }
            }
        }
    }

    DialogHandler { id: handler }
}
