import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "components"
import "view"

import Artix.Handlers
import Artix.Core
import Artix.Gui

/**
 * @brief Форма просмотра текстовой информации
 */
FullscreenDialog {

    contentItem: RowLayout {
        spacing: 0
        Rectangle {
            Layout.fillWidth: true
            Layout.fillHeight: true
            color: Style.parameter("color.modalBackground")
            Flickable {
                id: flickable
                anchors.fill: parent
                contentHeight: content.implicitHeight
                Column {
                    id: content
                    spacing: 32
                    BasicLabel {
                        Style.class: "textBrowserTitle"
                        leftPadding: 24
                        topPadding: 16
                        rightPadding: 24
                        width: flickable.width
                        Tr { tr: params.title }
                    }
                    StyledTextEdit {
                        Style.class: "textBrowserMessage"
                        width: flickable.width
                        Tr { tr: params.text }
                        font.family: params.font ?? Style.text.font.family
                        font.pixelSize: params.fontSize ?? Style.text.font.size
                        leftPadding: 24
                        bottomPadding: 16
                        rightPadding: 24
                        clip: true
                        textFormat: params.textFormat
                        enabled: false
                        wrapMode: TextEdit.Wrap
                    }
                }
                ScrollBar.vertical: ScrollBar {
                    id: scrollBar
                    Timer {
                        id: scrollTimer
                        interval: 2500
                        onTriggered: parent.active = false
                    }
                    onActiveChanged: scrollTimer.start()
                }
            }
        }
        Item {
            Layout.fillHeight: true
            Layout.preferredWidth: 304
            TopPanel {
                anchors { left: parent.left; top: parent.top; right: parent.right }
                anchors.leftMargin: 24
                hideUserName: true
            }
            ColumnLayout {
                anchors { left: parent.left; right: parent.right; bottom: parent.bottom; margins: 24 }
                spacing: 8
                BasicButton {
                    Style.class: "textBrowserCancel"
                    Layout.fillWidth: true
                    Layout.preferredHeight: 68
                    Tr { code: "backButton"; defaultMessage: "Назад" }
                    onClicked: handler.sendAnswer()
                }
            }
        }
    }

    DialogHandler { id: handler }
}
