import QtQuick
import QtQuick.Controls.impl
import QtQuick.Templates as T

import Artix.Gui
import Artix.Core

/**
 * @brief Кнопка "переключатель"
 */
T.RadioButton {
    id: control
    Style.type: "radioButton"
    Style.class: "default"

    implicitWidth: Math.max(implicitBackgroundWidth + leftInset + rightInset,
                            implicitContentWidth + leftPadding + rightPadding)
    implicitHeight: Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             implicitContentHeight + topPadding + bottomPadding,
                             implicitIndicatorHeight + topPadding + bottomPadding)

    padding: 16
    spacing: 8

    indicator: Rectangle {
        implicitWidth: 26
        implicitHeight: 26
        anchors {
            left: control.mirrored ? undefined : control.left
            right: !control.mirrored ? undefined : control.right
            leftMargin: control.leftPadding; rightMargin: control.rightPadding
            verticalCenter: parent.verticalCenter
        }

        radius: width / 2
        color: control.Style.indicator.background.color
        border {
            width: control.Style.indicator.background.border.width
            color: control.Style.indicator.background.border.color
        }

        Rectangle {
            x: (parent.width - width) / 2
            y: (parent.height - height) / 2
            width: 13; height: 13
            radius: width / 2
            border {
                width: control.Style.indicator.content.border.width
                color: control.Style.indicator.content.border.color
            }
            color: control.Style.indicator.content.color
            visible: control.checked

            Behavior on color { ColorAnimation { duration: 200 }}
        }

        Behavior on color { ColorAnimation { duration: 200 }}
    }

    contentItem: CheckLabel {
        leftPadding: !control.mirrored ? control.indicator.width + control.spacing : 0
        rightPadding: control.mirrored ? control.indicator.width + control.spacing : 0
        text: control.text
        font: control.Style.text.font
        color: control.Style.text.color
        wrapMode: Text.Wrap
    }

    background: Rectangle {
        color: control.Style.background.color
        border.color: control.Style.background.border.color
        border.width: control.Style.background.border.width
        radius: control.Style.background.radius

        Behavior on color { ColorAnimation { duration: 150 }}
    }
}
