import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"

import Artix.Core
import Artix.Gui
import Artix.Models

/**
 * @brief Список пользователей для диалога при авторизации
 */
Page {
    id: root
    signal close()

    clip: true
    header: Rectangle {
        height: 104
        color: Style.parameter("color.lightBackground")
        BasicLabel {
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.margins: 24
            Style.class: "authUsers"
            Tr { code: "authorizationUsers"; defaultMessage: "Пользователи" }
        }
        Rectangle {
            anchors.top: parent.bottom
            width: parent.width
            height: 5
            gradient: Gradient {
                orientation: Gradient.Vertical
                GradientStop { position: 0.0; color: Style.parameter("color.shadow") }
                GradientStop { position: 1.0; color: "transparent" }
            }
            opacity: 0.3
        }
    }
    ListView {
        anchors.fill: parent
        id: users
        model: AuthenticationModel {}

        // При масштабировании, списки могут отображаться с артефактами.
        // Рендерим с мультисемплированием в нужном разрешении. Не знаю за счет чего, но проблему это решило.
        layer {
            enabled: mainWindow.multisampling
            samples: 2
            textureSize: Qt.size(width * mainWindow.scaleFactor, height * mainWindow.scaleFactor)
        }

        delegate: GroupBox {
            id: delegate
            height: 100 + (separator.visible ? separator.height : 0)
            width: users.width
            Style.class: "authUsersDelegate"

            Line {
                id: separator
                visible: index !== 0
                anchors.top: parent.top
                width: parent.width
                strokeWidth: 1
                color: Style.parameter("color.grayBorder")
            }
            Column {
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.margins: 24
                spacing: 8
                BasicLabel {
                    Style.class: "authUserName"
                    text: model.name
                }
                BasicLabel {
                    Style.class: "authUserRank"
                    text: model.rank
                }
            }
        }
        function getVisibleIndexRange() {
                let center_x = users.x + users.width / 2
                return [indexAt( center_x, users.y + users.contentY + 99),
                        indexAt( center_x, users.y + users.contentY + users.height - 99)]
            }
        function scrollUp() {
            let firstIndex = getVisibleIndexRange()[0]
            if (firstIndex === 0)
                return
            positionViewAtIndex(firstIndex - 1, ListView.Contain)
        }
        function scrollDown() {
            let lastIndex = getVisibleIndexRange()[1]
            if (lastIndex === users.count - 1)
                return
            positionViewAtIndex(lastIndex + 1, ListView.Contain)
        }
    }
    footer: Rectangle {
        height: 116
        color: Style.parameter("color.lightBackground")
        RowLayout {
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: parent.right
            anchors.margins: 24
            BasicButton {
                Layout.preferredWidth: 112
                Layout.preferredHeight: 68
                Style.class: "authBack"
                Tr { code: "authorizationUsersBack"; defaultMessage: "Назад" }
                onClicked: root.close()
            }
            Item { Layout.preferredWidth: 32 }
            BasicButton {
                Layout.preferredWidth: 68
                Layout.preferredHeight: 68
                Style.class: "authUp"
                icon: Style.parameter("icon.authArrowDown")
                onClicked: users.scrollDown()
            }
            Item { Layout.preferredWidth: 16 }
            BasicButton {
                Layout.preferredWidth: 68
                Layout.preferredHeight: 68
                Style.class: "authDown"
                icon: Style.parameter("icon.authArrowUp")
                onClicked: users.scrollUp()
            }
        }
        Rectangle {
            anchors.bottom: parent.top
            width: parent.width
            height: 5
            gradient: Gradient {
                orientation: Gradient.Vertical
                GradientStop { position: 0.0; color: "transparent" }
                GradientStop { position: 1.0; color: Style.parameter("color.shadow") }
            }
            opacity: 0.3
        }
    }
    background: Rectangle { color: Style.parameter("color.lightBackground") }
}
